@@ -28,7 +28,7 @@ class CodeResult(Result):
     description: str = field(init=False)
     location: CodeLocation = field(init=False)
 
-    def __init__(self, complete: bool, passed: bool, description: str, location: CodeLocation, **details):
-        super().__init__(complete=complete, passed=passed, details=details)
+    def __init__(self, complete: bool, passing: bool, description: str, location: CodeLocation, **details):
+        super().__init__(complete=complete, passing=passing, details=details)
         self.description = description
         self.location = location
